---
title: "**<title>** Package Documentation"
---

This page has been automatically generated by
pyp2qmd (Python package documentation to quarto),
converting the docstrings of all loaded functions
and methods available via `<title>` into
quarto markdown files (`.qmd`).


### Basic call

The basic structure can be set up using:

```
pyp2qmd init --package pyp2qmd --output_dir ../docs --overwrite
(cd _quarto && quarto render)
```

### Additional pages on initialization

`<title>` is used to document itself creating the documentation
you are currently looking at using a small script which adds
a series of pages on initialization. The script can be found
in the repository, see:

* <https://github.com/retostauffer/pyp2qmd/make_docs/main.py>


### Function reference

Contains the documentation/reference of all functions,
including description, usage, arguments, exceptions,
as well as evaluated examples.


### Class reference

The documentation/reference of all classes including
description, usge, arguments, _methods_, exceptions,
and evaluated examples (if any).

For each method listed on the class reference page,
a quarto markdown file is generated as well, altough
not listed in the navigation. The documentation can
be accessed by visiting the class reference, and then
click on the method of interest.

_Automatically generated: <date_and_time>_.

